@@ -190,9 +190,13 @@ impl<'a> FromPyObject<'a> for NashParameters {
                 "affiliate_code not included in nash params",
             ))?
             .extract()?;
-        let environment = match &env_str[..] {
-            "sandbox" => Ok(Environment::Sandbox),
-            "production" => Ok(Environment::Production),
+        let dev_url: Option<String> = py_dict
+            .get_item("dev_url")
+            .and_then(|dev_url| dev_url.extract().ok());
+        let environment = match (&env_str[..], dev_url) {
+            ("sandbox", _) => Ok(Environment::Sandbox),
+            ("production", _) => Ok(Environment::Production),
+            ("dev", dev_url) => Ok(Environment::Dev(&Box::leak(dev_url.to_string().into_boxed_str()))),
             _ => Err(PyException::new_err("not a valid nash environment")),
         }?;
         let timeout: u64 = py_dict
